# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["DocumentStatusEnum"]

DocumentStatusEnum: TypeAlias = Literal[10, 20, 30, 40, 50]
