# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["SignerStatusEnum"]

SignerStatusEnum: TypeAlias = Literal[4, 5, 10, 15, 20, 30, 35, 39, 40, 50, 60]
