# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["SignerSendReminderParams"]


class SignerSendReminderParams(TypedDict, total=False):
    text: str
    """custom message text, html will be stripped"""
