# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["PermissionsEnum"]

PermissionsEnum: TypeAlias = Literal[1, 2, 3, 4, 5, 6]
